@@ -12,6 +12,7 @@ local setmetatable = setmetatable
 local tonumber = tonumber
 local tostring = tostring
 local rawget = rawget
+local select = select
 --local error = error
 
 
@@ -23,7 +24,7 @@ end
 
 local _M = new_tab(0, 54)
 
-_M._VERSION = '0.26'
+_M._VERSION = '0.27'
 
 
 local common_cmds = {
@@ -67,7 +68,8 @@ end
 function _M.set_timeout(self, timeout)
     local sock = rawget(self, "_sock")
     if not sock then
-        return nil, "not initialized"
+        error("not initialized", 2)
+        return
     end
 
     return sock:settimeout(timeout)
@@ -199,7 +201,7 @@ local function _read_reply(self, sock)
 
     else
         -- when `line` is an empty string, `prefix` will be equal to nil.
-        return nil, "unkown prefix: \"" .. tostring(prefix) .. "\""
+        return nil, "unknown prefix: \"" .. tostring(prefix) .. "\""
     end
 end
 
